#
# spec file for package python-django-mptt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-mptt
Version:        0.16
Release:        1.1
Summary:        Modified Preorder Tree Traversal for Django Models
License:        MIT
URL:            https://github.com/django-mptt/django-mptt
Source:         https://github.com/django-mptt/django-mptt/archive/refs/tags/%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-django-js-asset
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module django-js-asset}
BuildRequires:  %{python_module model-bakery}
# /SECTION
%python_subpackages

%description
Utilities for implementing Modified Preorder Tree Traversal with your Django Models and working with trees of Model instances.

%prep
%setup -q -n django-mptt-%{version}
sed -i 's/from model_mommy import mommy/from model_bakery import baker as mommy/' tests/myapp/tests.py
sed -i 's/test_create_by_mommy_exception/_test_create_by_mommy_exception/' tests/myapp/tests.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=${PWD}
%python_expand $python tests/manage.py test -v2 --keepdb

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/mptt/
%{python_sitelib}/django[-_]mptt*/

%changelog
* Thu Jul 18 2024 Markéta Machová <mmachova@suse.com>
- Update to version 0.16
  * "Since I unfortunately still depend on django-mptt in prehistoric
    projects I took it upon me to make it runnable again. This doesn't
    mean I want to maintain the package."
  * Added support for Python 3.12, Django 5.0.
  * Dropped Python < 3.9, Django < 3.2.
  * Added support for the Django admin theme switcher.
  * Switched to hatchling.
  * Fixed get_cached_trees if there are multiple trees in the queryset.
* Tue Apr 23 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Switch to sle15_python_module_pythons to repair build on Leap
* Mon Oct 10 2022 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v0.14.0
* Tue Apr 12 2022 Misha Komarovskiy <zombah@gmail.com>
- Update to 0.13.4
* Wed Sep  1 2021 Misha Komarovskiy <zombah@gmail.com>
- Update to 0.13.2
* Mon Aug 30 2021 Misha Komarovskiy <zombah@gmail.com>
- Update to 0.13.1
* Fri Jul 16 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update spec file for multi-build
* Mon May 10 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to 0.12.0
  + No changelog available
* Thu Apr 23 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.11.0
  + No changelog available
* Tue Dec 11 2018 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to 0.9.1
  + No changelog available
* Wed Feb  7 2018 daniel.molkentin@suse.com
- Cleanup spec file
- Update to 0.9.0
  + No changelog available
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 0.6.0
  + No changelog available
- Use download url as source url
- Replace python-distribute with python-setuptools BuildRequires
- Add documentation from tarball
- Incompatible with SLE11 < SP3
* Mon Dec 10 2012 alexandre@exatati.com.br
- Update to 0.5.5:
  - Sorry, no changelog.
* Thu Aug 23 2012 alexandre@exatati.com.br
- Update to 0.5.3:
  - Sorry, no changelog.
* Tue Aug 21 2012 alexandre@exatati.com.br
- Update to 0.5.3:
  - Sorry, no changelog.
* Tue Jan  3 2012 alexandre@exatati.com.br
- Standard on spec file;
- License in SPDX format;
- Remove CFLAGS from build command;
- Change python-setuptools to python-distribute in Requires tag.
* Fri Nov 25 2011 nikolai@prokoschenko.de
- Update to 0.5.2.
* Thu Nov  4 2010 alexandre@exatati.com.br
- Update to 0.4.2.
* Thu Sep  2 2010 alexandre@exatati.com.br
- Update to 0.3;
- Spec file cleaned with spec-cleaner;
- Fixed URL and Author informations.
* Fri Nov 13 2009 alexandre@exatati.com.br
- Fixed spec file (Identation, License and BuildRoot);
- Building as noarch for openSUSE >= 11.2.
